@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+from PyQt4 import QtCore, QtGui
+
 import sys
 import os
 import random
@@ -36,15 +38,17 @@ def SetAlarm():
     if(data.demo==False): #We are on a N900
         event = alarm.Event()
         event.appid = 'SleepAnalyser'
-#        event.title = _('SleepAnalyser alarm')
-        event.message = _('Wake up (SleepAnalyser)')
+        txt=_('Wake up (SleepAnalyser)')
+        event.message =str(txt.encode( "utf-8" ))
 
         event.alarm_time = records.AlarmTime_seconds #in seconds
 
         action_snooze, action_stop = event.add_actions(2)
-        action_snooze.label = _('Snooze')
+        txt=_('Snooze')
+        action_snooze.label=str(txt.encode( "utf-8" ))
         action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
-        action_stop.label = _('Stop')
+        txt=_('Stop')
+        action_stop.label =str(txt.encode( "utf-8" ))
         action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
 
 
@@ -155,4 +159,4 @@ def ProcessAlarm():
 
 #    print "records.AlarmIsSet", records.AlarmIsSet
 #    print "data.AlarmIsActive:",  data.AlarmIsActive
-#    print ""
\ No newline at end of file
+#    print ""
