@@ -94,9 +94,9 @@ def LoadConfig():
         config.set('main', 'Xscale', str(data.Xscale))
 
     try:
-        data.Yscale = config.getint('main', 'Yscale')
+        data.Yscale_Movement = config.getint('main', 'Yscale_Movement')
     except:
-        config.set('main', 'Yscale', str(data.Yscale))
+        config.set('main', 'Yscale_Movement', str(data.Yscale_Movement_default))
 
     try:
         data.derivation_offset = config.getint('main', 'derivation_offset')
@@ -104,14 +104,14 @@ def LoadConfig():
         config.set('main', 'derivation_offset', str(data.derivation_offset))
 
     try:
-        data.FilterScale = config.getint('main', 'FilterScale')
+        data.Yscale_Sleep_Pattern = config.getint('main', 'Yscale_Sleep_Pattern')
     except:
-        config.set('main', 'FilterScale', str(data.FilterScale))
+        config.set('main', 'Yscale_Sleep_Pattern', str(data.Yscale_Sleep_Pattern_default))
 
     try:
-        data.Sleep_Pattern_Yoffset = config.getint('main', 'Sleep_Pattern_Yoffset')
+        data.Yoffset_Sleep_Pattern = config.getint('main', 'Yoffset_Sleep_Pattern')
     except:
-        config.set('main', 'Sleep_Pattern_Yoffset', str(data.Sleep_Pattern_Yoffset))
+        config.set('main', 'Yoffset_Sleep_Pattern', str(data.Yoffset_Sleep_Pattern_default))
 
     try:
         data.limitMovement = config.getint('main', 'limitMovement')
