@@ -466,9 +466,12 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
             if(y<18):
                 y=33
-                paint.drawLine(data.GraphBitMapLen-35, y-21,    data.GraphBitMapLen-35, y-30) #arrow
-                paint.drawLine(data.GraphBitMapLen-35, y-30,    data.GraphBitMapLen-32, y-27) #arrow
-                paint.drawLine(data.GraphBitMapLen-35, y-30,    data.GraphBitMapLen-38, y-27) #arrow
+                #draw arrow
+                xa=data.GraphBitMapLen-37
+                ya=y-21
+                paint.drawLine(xa, ya,    xa, ya-9) #arrow
+                paint.drawLine(xa, ya-9,    xa-3, ya-6) #arrow
+                paint.drawLine(xa, ya-9,    xa+3, ya-6) #arrow
             elif(y<33):
                 y=y+17
             paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
@@ -740,4 +743,4 @@ def PrintRecordData(ShowArray=True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
 
-    print "##########################################################"
\ No newline at end of file
+    print "##########################################################"
