@@ -15,18 +15,22 @@ def IsCompiled():
 
 
 
-def sleep_filter(ar, l, filter,  shift, scale, max, min, limitMovement):
+
+
+
+
+def sleep_filter(ar, arlen, filter,  shift, Yscale, Yoffset, Ymax, Ymin, limitMovement):
     len_filter=len(filter)
 
-    ar_ret=[0]*(l+len_filter)
+    ar_ret=[0]*(arlen+len_filter)
 
-    for i in range(0, l): #loop arrData
+    for i in range(0, arlen): #loop arrData
         if(ar[i] > limitMovement): #limit peack values
             ar[i] = limitMovement
 
 
 
-    for i in range(0, l): #loop arrData
+    for i in range(0, arlen): #loop arrData
         value=ar[i]
 
         for p in range(0,  len_filter-1): #loop arrFilter
@@ -34,13 +38,13 @@ def sleep_filter(ar, l, filter,  shift, scale, max, min, limitMovement):
 
 
 
-    for i in range(0, l): #loop arrData
-        value=ar_ret[i] * scale/80000 #scale
+    for i in range(0, arlen): #loop arrData
+        value=(ar_ret[i] * Yscale/80000)-Yoffset #Yscale
 
-        if(value > max): #check range over/unterrun
-            ar_ret[i] = max #-int(random.uniform(1, 2))
-        elif(value < min):
-            ar_ret[i] =min
+        if(value > Ymax): #check range over/unterrun
+            ar_ret[i] = Ymax #-int(random.uniform(1, 2))
+        elif(value < Ymin):
+            ar_ret[i] =Ymin
         else:
             ar_ret[i]=value
 
@@ -56,4 +60,4 @@ if __name__ == '__main__':
     IsCompiled()
     arTest=[1, 2, 3, 4, 5, 6, 7, 8, 9]
     arFiltertest=[1, 2, 3]
-    sleep_filter(arTest, 1, arFiltertest, 1, 20, 120, 13, 250)
+    sleep_filter(arTest, 1, arFiltertest, 1, 20, 10, 120, 13, 250)
