@@ -226,7 +226,7 @@ def main():
 def EditUserName():
 #      r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
 #        if(r[1]==True): #OK pressed
-    r = QInputDialog.getText(None, "SleepAnalyser", _("Please enter your name.\nIt will be used in the records file, this makes it easier\nwhen you want to share your sleep pattern with others."), 0,  data.user)
+    r = QInputDialog.getText(None, _("SleepAnalyser"), _("Please enter your name.\nIt will be used in the records file, this makes it easier\nwhen you want to share your sleep pattern with others."), 0,  data.user)
 #    if(r != ""):
     if(r[1]==True): #OK pressed
         data.user=unicode(r[0])
@@ -451,13 +451,11 @@ def MoveTrigger(direction):
 
 
 def About(ui):
-    QtGui.QMessageBox.about(ui, _("About")+" SleepAnalyser "+str(data.version)+"-"+str(data.build), _("Copyright 2010 by George Ruinelli with great support from the MAEMO community")+"\n"+\
+    QtGui.QMessageBox.about(ui, _("About")+" "+_("SleepAnalyser")+" "+str(data.version)+"-"+str(data.build), _("Copyright 2010 by George Ruinelli with great support from the MAEMO community")+"\n"+\
     _("Contact:")+" george@ruinelli.ch\n" +\
     _("Website:")+" http://www.ruinelli.ch/sleepanalyser/\n\n"+\
-    _("Translations:")+\
-    "\nEnglish, Deutsch: George Ruinelli\n"+\
-    "Francais: Fred Kwame Ayanfu & Guy Roussil\n"+\
-    "Dutch: Fred Kwame Ayanful")
+    _("Translations:")+"\n" +\
+    data.translation_copyrights)
 
 
 
@@ -505,7 +503,7 @@ class frmStartWindow(QMainWindow):
 
 
         #set texts
-        self.setWindowTitle("SleepAnalyser")
+        self.setWindowTitle(_("SleepAnalyser"))
         self.ui.bView.setText(_("View records"))
         self.ui.bCollecting.setText(_("Start recording only"))
         self.ui.bSetAlarm.setText(_("Set alarm and\nstart recording"))
@@ -702,12 +700,12 @@ class frmRecordWindow(QMainWindow):
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
             self.ui.lblAnimation.setPixmap(QtGui.QPixmap(data.app_path+"img/anim/0.png"))
 
-        self.setWindowTitle("SleepAnalyser ("+_("Recording")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Recording")+")")
         self.ui.lblElapsedTime.setText(_("Elapsed time:")+" 0")
         self.ui.bStop.setText(_("Stop"))
         self.ui.lblAlarmTime.setText(_("Alarm time: (no alarm set)"))
         self.ui.lblStatus2.setText(_("Status:"))
-        self.ui.lblStatus.setText(_("Loading..."))
+        self.ui.lblStatus.setText(_("Loading record..."))
         self.ui.lblstate1.setText(_("Awake"))
         self.ui.lblstate2.setText(_("Light sleep"))
         self.ui.lblstate3.setText(_("Deep sleep"))
@@ -949,7 +947,7 @@ class frmViewWindow(QMainWindow):
             self.ui.bStatistics.setIcon(QIcon(data.app_path+"img/"+"klipper_dock.png"))
 
 
-        self.setWindowTitle("SleepAnalyser ("+_("View")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("View")+")")
         self.ui.lblstate1.setText(_("Awake"))
         self.ui.lblstate2.setText(_("Light sleep"))
         self.ui.lblstate3.setText(_("Deep sleep"))
@@ -1322,10 +1320,10 @@ class frmViewWindow(QMainWindow):
 
 
 
-    def UpdateStatus(self, text): ##(Class ViewWindow)
-        self.ui.lblStatus.setText(text)
-        self.ui.lblStatus.show()
-        app.processEvents() #force ui update
+#    def UpdateStatus(self, text): ##(Class ViewWindow)
+#        self.ui.lblStatus.setText(text)
+#        self.ui.lblStatus.show()
+#        app.processEvents() #force ui update
 
 
 
@@ -1362,7 +1360,7 @@ class frmHelpWindow(QMainWindow):
         txt=QtGui.QApplication.translate("", txt, None, QtGui.QApplication.UnicodeUTF8)
         self.ui.textBrowser.setHtml(txt)
 
-        self.setWindowTitle("SleepAnalyser ("+_("Help")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Help")+")")
 
 
 
@@ -1416,19 +1414,22 @@ class frmConfigWindow(QMainWindow):
 
         self.setStyleSheet(data.UIStyle) #Add styles
 
-        self.setWindowTitle("SleepAnalyser ("+_("Settings")+")")
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_User), _("Name"))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_General), _("General"))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced_1), _("Advanced") +" 1")
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced_2), _("Advanced") +" 2")
+
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Settings")+")")
         self.ui.cOfflineMode.setText(_("Change to Offline Mode while recording"))
         self.ui.cSilentProfile.setText(_("Change to Silent Profile while recording"))
         self.ui.cStopAfterAlarm.setText(_("Stop recording after alarm occured"))
         self.ui.lblUser.setText(_("User name:"))
         self.ui.bEditUserName.setText(_("Change"))
-        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_General), _("General"))
         self.ui.lblDelayStart.setText(_("Start delay:"))
         self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):"))
         self.ui.lblYscale_Sleep_Pattern.setText(_("Y scaling sleep graph (blue):"))
         self.ui.lblYoffset_Sleep_Pattern.setText(_("Y offset sleep graph (blue):"))
-        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced_1), _("Advanced"+" 1"))
-        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced_2), _("Advanced"+" 2"))
+
 #        self.ui.lblMore.setText(_("More settings can be changed at your own risk in the file\n~/.SleepAnalyer/SleepAnalyser.conf."))
 #        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_More), _("More"))
         self.ui.bOK.setText(_("OK"))
@@ -1612,7 +1613,7 @@ class frmDateWindow(QMainWindow):
 
         self.ui.cal.showToday()
 
-        self.setWindowTitle("SleepAnalyser ("+_("Select date")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Select date")+")")
 
 
     ###########################################################################
@@ -1674,7 +1675,7 @@ class frmAdditionalInfoWindow(QMainWindow):
 
         self.setStyleSheet(data.UIStyle) #Add styles
 
-        self.setWindowTitle("SleepAnalyser ("+_("Record Info\'s")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Record Info\'s")+")")
 
 
     ###########################################################################
@@ -1790,7 +1791,7 @@ class frmAlarmTimeWindow(QMainWindow):
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
 
-        self.setWindowTitle("SleepAnalyser ("+_("Set alarm")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Set alarm")+")")
         txt=_("The Alarm will go off sometimes during the set time window (as soon as your movement is over the trigger level), but latest at the set alarm time.")
         self.ui.lblNote.setText(txt)
         self.ui.bSetAlarm.setText(_("Set alarm"))
@@ -1909,7 +1910,7 @@ class frmAskForKeepWindow(QMainWindow):
             self.ui.bstop_removeRecord.setIcon(QIcon(data.app_path+"img/"+"edittrash.png"))
             self.ui.bcontinue.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
 
-        self.setWindowTitle("SleepAnalyser ("+_("Recording")+")")
+        self.setWindowTitle(_("SleepAnalyser")+" ("+_("Recording")+")")
         self.ui.bcontinue.setText(_("Continue recording"))
         self.ui.bstop_keepRecord.setText(_("Stop recording and keep the record"))
         self.ui.bstop_removeRecord.setText(_("Stop recording and delete the record"))
